@@ -72,6 +72,11 @@ if settings.DEBUG:
 class Recipe(object):
     def __init__(self, buildout, name, options):
         self.log = logging.getLogger(name)
+        eggs = options.get('eggs', '')
+        has_django = re.findall(r'(?<![^\s])django[\s=$]', eggs, re.MULTILINE | re.UNICODE | re.IGNORECASE)
+        if not has_django:
+            eggs = 'Django\n%s' % eggs
+            options['eggs'] = eggs
         self.egg = zc.recipe.egg.Egg(buildout, options['recipe'], options)
 
         self.buildout, self.name, self.options = buildout, name, options
