@@ -72,6 +72,30 @@ class TestRecipe(unittest.TestCase):
                        {'recipe': 'cykooz.djangorecipe'}).options.copy() for i in range(2)])
 
 
+    def test_add_django_to_eggs(self):
+        eggs = 'psycopg2\ndjango-view-shortcuts'
+        recipe = Recipe({
+                         'buildout': self.default_buildout_options,
+                         'python-version': {'executable': sys.executable}
+                        },
+                        'django',
+                        {'recipe': 'cykooz.djangorecipe',
+                         'eggs': eggs
+                        })
+        self.assertTrue(recipe.options.get('eggs', '').startswith('Django'))
+        
+        eggs = 'mock\nDjango == 1.2.5'
+        recipe = Recipe({
+                         'buildout': self.default_buildout_options,
+                         'python-version': {'executable': sys.executable}
+                        },
+                        'django',
+                        {'recipe': 'cykooz.djangorecipe',
+                         'eggs': eggs
+                        })
+        self.assertEqual(recipe.options.get('eggs', ''), eggs)
+
+
     def test_create_file(self):
         # The create file helper should create a file at a certain
         # location unless it already exists. We will need a
